package com.titan.ship;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.NoSuchEntityException;
import javax.ejb.ObjectNotFoundException;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.sql.DataSource;

/**
 * Bean implementation class for Enterprise Bean: Ship
 */
public class ShipBean implements javax.ejb.EntityBean {
	public Integer id;
	public String name;
	public int capacity;
	public double tonnage;
	private DataSource ds = null; // cached data source
	final String dbDatasource = "java:comp/env/jdbc/TitanDS";

	private javax.ejb.EntityContext myEntityCtx;
	/**
	 * ejbActivate
	 */
	public void ejbActivate() {
	}
	/**
	 * ejbLoad
	 */
	public void ejbLoad() {
		Integer primaryKey = (Integer) myEntityCtx.getPrimaryKey();
		Connection con = null;
		PreparedStatement ps = null;
		ResultSet result = null;
		try {
			con = getConnection();
			ps =
				con.prepareStatement(
					"SELECT NAME, CAPACITY, TONNAGE FROM MZ.SHIP WHERE ID = ?");
			ps.setInt(1, primaryKey.intValue());
			result = ps.executeQuery();
			if (result.next()) {
				id = primaryKey;
				name = result.getString("NAME");
				capacity = result.getInt("CAPACITY");
				tonnage = result.getDouble("TONNAGE");
			} else {
				throw new NoSuchEntityException();
			}
		} catch (SQLException se) {
			throw new EJBException(se);
		} finally {
			try {
				if (result != null)
					result.close();
				if (ps != null)
					ps.close();
				if (con != null)
					con.close();
			} catch (SQLException se) {
				se.printStackTrace();
			}
		}
		System.out.println("ShipBean: ejbLoad");
	}
	/**
	 * ejbPassivate
	 */
	public void ejbPassivate() {
	}
	/**
	 * ejbRemove
	 */
	public void ejbRemove() throws javax.ejb.RemoveException {
		Connection con = null;
		PreparedStatement ps = null;
		try {
			con = getConnection();
			ps = con.prepareStatement("DELETE FROM MZ.SHIP WHERE ID = ?");
			ps.setInt(1, id.intValue());
			if (ps.executeUpdate() != 1) {
				throw new EJBException("ejbRemove");
			}
		} catch (SQLException se) {
			throw new EJBException(se);
		} finally {
			try {
				if (ps != null)
					ps.close();
				if (con != null)
					con.close();
			} catch (SQLException se) {
				se.printStackTrace();
			}
		}
		System.out.println("ShipBean: ejbRemove");
	}
	/**
	 * ejbStore
	 */
	public void ejbStore() {
		Connection con = null;
		PreparedStatement ps = null;
		try {
			con = getConnection();
			ps =
				con.prepareStatement(
					"UPDATE MZ.SHIP SET NAME = ?, CAPACITY = ?, "
						+ "TONNAGE = ? WHERE ID = ?");
			ps.setString(1, name);
			ps.setInt(2, capacity);
			ps.setDouble(3, tonnage);
			ps.setInt(4, id.intValue());
			if (ps.executeUpdate() != 1) {
				throw new NoSuchEntityException("ejbStore");
			}
		} catch (SQLException se) {
			throw new EJBException(se);
		} finally {
			try {
				if (ps != null)
					ps.close();
				if (con != null)
					con.close();
			} catch (SQLException se) {
				se.printStackTrace();
			}
		}
		System.out.println("ShipBean: ejbStore");
	}
	/**
	 * getEntityContext
	 */
	public javax.ejb.EntityContext getEntityContext() {
		return myEntityCtx;
	}
	/**
	 * setEntityContext
	 */
	public void setEntityContext(javax.ejb.EntityContext ctx) {
		myEntityCtx = ctx;
	}
	/**
	 * unsetEntityContext
	 */
	public void unsetEntityContext() {
		myEntityCtx = null;
	}
	/**
	 * ejbCreate
	 */
	public java.lang.Integer ejbCreate(Integer id, String name)
		throws javax.ejb.CreateException {

		this.id = id;
		this.name = name;
		this.capacity = 0;
		this.tonnage = 0;
		Connection con = null;
		PreparedStatement ps = null;
		try {
			con = getConnection();
			ps = con.prepareStatement(
					"INSERT INTO MZ.SHIP (ID, NAME, CAPACITY, TONNAGE) "
						+ "VALUES (?,?,?,?)");
			ps.setInt(1, id.intValue());
			ps.setString(2, name);
			ps.setInt(3, capacity);
			ps.setDouble(4, tonnage);
			if (ps.executeUpdate() != 1) {
				throw new CreateException("Failed to add Ship to database");
			}
			System.out.println("ShipBean: ejbCreate : [id = " + id +"]");
			return id;
		} catch (SQLException se) {
			throw new EJBException(se);
		} finally {
			try {
				if (ps != null)
					ps.close();
				if (con != null)
					con.close();
			} catch (SQLException se) {
				se.printStackTrace();
			}
		}
	}
	/**
	 * ejbPostCreate
	 */
	public void ejbPostCreate(Integer id, String name)
		throws javax.ejb.CreateException {
	}
	/**
	 * ejbFindByPrimaryKey
	 */
	public java.lang.Integer ejbFindByPrimaryKey(java.lang.Integer primaryKey)
		throws javax.ejb.FinderException {
		Connection con = null;
		PreparedStatement ps = null;
		ResultSet result = null;
		try {
			con = this.getConnection();
			ps = con.prepareStatement("SELECT ID FROM MZ.SHIP WHERE ID = ?");
			ps.setInt(1, primaryKey.intValue());
			result = ps.executeQuery();
			if (!result.next()) {
				throw new ObjectNotFoundException(
					"Cannot find Ship with id = " + id);
			}
		} catch (SQLException se) {
			throw new EJBException(se);
		} finally {
			try {
				if (result != null)
					result.close();
				if (ps != null)
					ps.close();
				if (con != null)
					con.close();
			} catch (SQLException se) {
				se.printStackTrace();
			}
		}
		return primaryKey;
	}

	public String getName() {
		return name;
	}

	public void setName(String n) {
		name = n;
	}

	public void setCapacity(int cap) {
		capacity = cap;
	}

	public int getCapacity() {
		return capacity;
	}

	public double getTonnage() {
		return tonnage;
	}

	public void setTonnage(double tons) {
		tonnage = tons;
	}

	private Connection getConnection() throws SQLException {
		if (ds == null) {
			try {
				InitialContext ctx = new InitialContext();
				ds = (DataSource) ctx.lookup(dbDatasource);
			} catch (NamingException e) {
				throw new SQLException(e.getMessage());
			}
		}
		return ds.getConnection();
	}
}
